@@ -1,28 +1,28 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef IMPORTEXPORTENGINE_H
-#define IMPORTEXPORTENGINE_H
+#pragma once
 
+#include <Akonadi/Collection>
 #include <QObject>
-#include <AkonadiCore/Collection>
 
-#include "kaddressbook_importexport_export.h"
 #include "contactlist.h"
+#include "kaddressbook_importexport_export.h"
 
 class QProgressDialog;
 class KJob;
 
-namespace KAddressBookImportExport {
+namespace KAddressBookImportExport
+{
 class KADDRESSBOOK_IMPORTEXPORT_EXPORT ImportExportEngine : public QObject
 {
     Q_OBJECT
 public:
     explicit ImportExportEngine(QObject *parent = nullptr);
-    ~ImportExportEngine();
+    ~ImportExportEngine() override;
     void setContactList(const ContactList &contacts);
 
     void importContacts();
@@ -44,4 +44,3 @@ private:
 };
 }
 
-#endif // IMPORTEXPORTENGINE_H
